@@ -27,6 +27,7 @@ from .models import OAuthUserProxy, Scope
 from .provider import oauth2
 
 from invenio_oauth2server._compat import monkey_patch_werkzeug  # noqa isort:skip
+
 monkey_patch_werkzeug()  # noqa isort:skip
 from flask_oauthlib.contrib.oauth2 import bind_cache_grant  # noqa isort:skip
 
@@ -43,12 +44,13 @@ class _OAuth2ServerState(object):
         oauth2.init_app(app)
 
         # Flask-OAuthlib does not support CACHE_REDIS_URL
-        if app.config['OAUTH2_CACHE_TYPE'] == 'redis' and app.config.get(
-                'CACHE_REDIS_URL'):
+        if app.config["OAUTH2_CACHE_TYPE"] == "redis" and app.config.get(
+            "CACHE_REDIS_URL"
+        ):
             from redis import from_url as redis_from_url
+
             app.config.setdefault(
-                'OAUTH2_CACHE_REDIS_HOST',
-                redis_from_url(app.config['CACHE_REDIS_URL'])
+                "OAUTH2_CACHE_REDIS_HOST", redis_from_url(app.config["CACHE_REDIS_URL"])
             )
 
         # Configures an OAuth2Provider instance to use configured caching
@@ -57,7 +59,7 @@ class _OAuth2ServerState(object):
 
         # Disables oauthlib's secure transport detection in in debug mode.
         if app.debug or app.testing:
-            os.environ['OAUTHLIB_INSECURE_TRANSPORT'] = '1'
+            os.environ["OAUTHLIB_INSECURE_TRANSPORT"] = "1"
 
         if entry_point_group:
             self.load_entry_point_group(entry_point_group)
@@ -70,7 +72,8 @@ class _OAuth2ServerState(object):
         :returns: A list of tuples (id, scope).
         """
         return [
-            (k, scope) for k, scope in sorted(self.scopes.items())
+            (k, scope)
+            for k, scope in sorted(self.scopes.items())
             if not exclude_internal or not scope.is_internal
         ]
 
@@ -89,9 +92,7 @@ class _OAuth2ServerState(object):
 
         :param entry_point_group: The entrypoint group name to load plugins.
         """
-        for ep in set(importlib_metadata.entry_points(
-            group=entry_point_group
-        )):
+        for ep in set(importlib_metadata.entry_points(group=entry_point_group)):
             self.register_scope(ep.load())
 
     def load_obj_or_import_string(self, value):
@@ -110,9 +111,7 @@ class _OAuth2ServerState(object):
     @cached_property
     def jwt_verification_factory(self):
         """Load default JWT verification factory."""
-        return self.load_obj_or_import_string(
-            'OAUTH2SERVER_JWT_VERIFICATION_FACTORY'
-        )
+        return self.load_obj_or_import_string("OAUTH2SERVER_JWT_VERIFICATION_FACTORY")
 
 
 class InvenioOAuth2Server(object):
@@ -126,8 +125,7 @@ class InvenioOAuth2Server(object):
         if app:
             self._state = self.init_app(app, **kwargs)
 
-    def init_app(self, app, entry_point_group='invenio_oauth2server.scopes',
-                 **kwargs):
+    def init_app(self, app, entry_point_group="invenio_oauth2server.scopes", **kwargs):
         """Flask application initialization.
 
         :param app: An instance of :class:`flask.Flask`.
@@ -137,7 +135,7 @@ class InvenioOAuth2Server(object):
         self.init_config(app)
         state = _OAuth2ServerState(app, entry_point_group=entry_point_group)
 
-        app.extensions['invenio-oauth2server'] = state
+        app.extensions["invenio-oauth2server"] = state
         return state
 
     def init_config(self, app):
@@ -146,20 +144,22 @@ class InvenioOAuth2Server(object):
         :param app: An instance of :class:`flask.Flask`.
         """
         app.config.setdefault(
-            'OAUTH2SERVER_BASE_TEMPLATE',
-            app.config.get('BASE_TEMPLATE',
-                           'invenio_oauth2server/base.html'))
+            "OAUTH2SERVER_BASE_TEMPLATE",
+            app.config.get("BASE_TEMPLATE", "invenio_oauth2server/base.html"),
+        )
         app.config.setdefault(
-            'OAUTH2SERVER_COVER_TEMPLATE',
-            app.config.get('COVER_TEMPLATE',
-                           'invenio_oauth2server/base.html'))
+            "OAUTH2SERVER_COVER_TEMPLATE",
+            app.config.get("COVER_TEMPLATE", "invenio_oauth2server/base.html"),
+        )
         app.config.setdefault(
-            'OAUTH2SERVER_SETTINGS_TEMPLATE',
-            app.config.get('SETTINGS_TEMPLATE',
-                           'invenio_oauth2server/settings/base.html'))
+            "OAUTH2SERVER_SETTINGS_TEMPLATE",
+            app.config.get(
+                "SETTINGS_TEMPLATE", "invenio_oauth2server/settings/base.html"
+            ),
+        )
 
         for k in dir(config):
-            if k.startswith('OAUTH2SERVER_') or k.startswith('OAUTH2_'):
+            if k.startswith("OAUTH2SERVER_") or k.startswith("OAUTH2_"):
                 app.config.setdefault(k, getattr(config, k))
 
     def __getattr__(self, name):
@@ -178,18 +178,18 @@ def verify_oauth_token_and_set_current_user():
     """
     # Since this function can be evoked multiple times
     # we add a check to not run it if it has already run.
-    if hasattr(request, 'oauth_verify_has_run'):
+    if hasattr(request, "oauth_verify_has_run"):
         return
 
     for func in oauth2._before_request_funcs:
         func()
 
-    if not hasattr(request, 'oauth') or not request.oauth:
+    if not hasattr(request, "oauth") or not request.oauth:
         scopes = []
         try:
             valid, req = oauth2.verify_request(scopes)
         except ValueError:
-            abort(400, 'Error trying to decode a non urlencoded string.')
+            abort(400, "Error trying to decode a non urlencoded string.")
 
         for func in oauth2._after_request_funcs:
             valid, req = func(valid, req)
@@ -197,7 +197,7 @@ def verify_oauth_token_and_set_current_user():
         if valid:
             request.oauth = req
 
-    if hasattr(request, 'oauth'):
+    if hasattr(request, "oauth"):
         request.skip_csrf_check = True
 
     request.oauth_verify_has_run = True
@@ -222,10 +222,12 @@ class InvenioOAuth2ServerREST(object):
         self.init_config(app)
 
         allowed_urlencode_chars = app.config.get(
-            'OAUTH2SERVER_ALLOWED_URLENCODE_CHARACTERS')
+            "OAUTH2SERVER_ALLOWED_URLENCODE_CHARACTERS"
+        )
         if allowed_urlencode_chars:
             InvenioOAuth2ServerREST.monkeypatch_oauthlib_urlencode_chars(
-                allowed_urlencode_chars)
+                allowed_urlencode_chars
+            )
         # add check to skip csrf validation if oauth request
         csrf.before_csrf_protect(verify_oauth_token_and_set_current_user)
         app.before_request(verify_oauth_token_and_set_current_user)
@@ -233,8 +235,9 @@ class InvenioOAuth2ServerREST(object):
     def init_config(self, app):
         """Initialize configuration."""
         app.config.setdefault(
-            'OAUTH2SERVER_ALLOWED_URLENCODE_CHARACTERS',
-            getattr(config, 'OAUTH2SERVER_ALLOWED_URLENCODE_CHARACTERS'))
+            "OAUTH2SERVER_ALLOWED_URLENCODE_CHARACTERS",
+            getattr(config, "OAUTH2SERVER_ALLOWED_URLENCODE_CHARACTERS"),
+        )
 
     @staticmethod
     def monkeypatch_oauthlib_urlencode_chars(chars):
@@ -277,8 +280,8 @@ class InvenioOAuth2ServerREST(object):
         if modified_chars != original_special_chars:
             warnings.warn(
                 'You are overriding the default OAuthlib "URL encoded" set of '
-                'valid characters. Make sure that the characters defined in '
-                'oauthlib.common.urlencoded are indeed limitting your needs.',
-                RuntimeWarning
+                "valid characters. Make sure that the characters defined in "
+                "oauthlib.common.urlencoded are indeed limitting your needs.",
+                RuntimeWarning,
             )
             oauthlib_commmon.urlencoded = always_safe | modified_chars
